ecs_ptr_from_json

Function ecs_ptr_from_json 

pub unsafe extern "C" fn ecs_ptr_from_json(
    world: *const ecs_world_t,
    type_: u64,
    ptr: *mut c_void,
    json: *const i8,
    desc: *const ecs_from_json_desc_t,
) -> *const i8
Parse JSON string into value. This operation parses a JSON expression into the provided pointer. The memory pointed to must be large enough to contain a value of the used type.

@param world The world. @param type The type of the expression to parse. @param ptr Pointer to the memory to write to. @param json The JSON expression to parse. @param desc Configuration parameters for deserializer. @return Pointer to the character after the last one read, or NULL if failed.