ecs_value_fini

Function ecs_value_fini 

pub unsafe extern "C" fn ecs_value_fini(
    world: *const ecs_world_t,
    type_: u64,
    ptr: *mut c_void,
) -> i32
Destruct a value

@param world The world. @param type The type of the value to destruct. @param ptr Pointer to constructed value of type ‘type’. @return Zero if success, nonzero if failed.