ecs_unit_desc_t

Struct ecs_unit_desc_t 

#[repr(C)]
pub struct ecs_unit_desc_t { pub entity: u64, pub symbol: *const i8, pub quantity: u64, pub base: u64, pub over: u64, pub translation: ecs_unit_translation_t, pub prefix: u64, }
Used with ecs_unit_init.

Fields

entity: u64

Existing entity to associate with unit (optional)

symbol: *const i8

Unit symbol, e.g. “m”, “%”, “g”. (optional)

quantity: u64

Unit quantity, e.g. distance, percentage, weight. (optional)

base: u64

Base unit, e.g. “meters” (optional)

over: u64

Over unit, e.g. “per second” (optional)

translation: ecs_unit_translation_t

Translation to apply to derived unit (optional)

prefix: u64

Prefix indicating order of magnitude relative to the derived unit. If set together with “translation”, the values must match. If translation is not set, setting prefix will autopopulate it. Additionally, setting the prefix will enforce that the symbol (if set) is consistent with the prefix symbol + symbol of the derived unit. If the symbol is not set, it will be auto populated.