pub unsafe extern "C" fn ecs_record_get_entity(
record: *const ecs_record_t,
) -> u64Expand description
Get entity corresponding with record. This operation only works for entities that are not empty.
@param record The record for which to obtain the entity id.