pub unsafe extern "C" fn ecs_table_swap_rows(
world: *mut ecs_world_t,
table: *mut ecs_table_t,
row_1: i32,
row_2: i32,
)Expand description
Swaps two elements inside the table. This is useful for implementing custom table sorting algorithms. @param world The world @param table The table to swap elements in @param row_1 Table element to swap with row_2 @param row_2 Table element to swap with row_1